==> 2.4.zip: piwigo/language/et_EE/upgrade.lang.php <==
<?php
// +-----------------------------------------------------------------------+
// | Piwigo - a PHP based photo gallery                                    |
// +-----------------------------------------------------------------------+
// | Copyright(C) 2008-2012 Piwigo Team                  http://piwigo.org |
// | Copyright(C) 2003-2008 PhpWebGallery Team    http://phpwebgallery.net |
// | Copyright(C) 2002-2003 Pierrick LE GALL   http://le-gall.net/pierrick |
// +-----------------------------------------------------------------------+
// | This program is free software; you can redistribute it and/or modify  |
// | it under the terms of the GNU General Public License as published by  |
// | the Free Software Foundation                                          |
// |                                                                       |
// | This program is distributed in the hope that it will be useful, but   |
// | WITHOUT ANY WARRANTY; without even the implied warranty of            |
// | MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the GNU      |
// | General Public License for more details.                              |
// |                                                                       |
// | You should have received a copy of the GNU General Public License     |
// | along with this program; if not, write to the Free Software           |
// | Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307, |
// | USA.                                                                  |
// +-----------------------------------------------------------------------+
$lang['All sub-albums of private albums become private'] = 'Privaatsete albumite kõik alam-albumid saavad samuti privaatseteks';
$lang['As a precaution, following plugins have been deactivated. You must check for plugins upgrade before reactiving them:'] = 'Ettevaatusabinõuks on järgmised pluginad deaktiveeritud. Sa pead vaatama kas neile on saadaval uuendusi, enne kui sa need aktiveerid.';
$lang['As a precaution, following themes have been deactivated. You must check for themes upgrade before reactiving them:'] = 'Ettevaatusabinõuks on järgmised teemad deaktiveeritud. Sa pead vaatama kas neile on saadaval uuendusi, enne kui sa need aktiveerid.';
$lang['In <i>%s</i>, before <b>?></b>, insert:'] = 'In <i>%s</i>, before <b>?></b>, insert:';
$lang['Only administrator can run upgrade: please sign in below.'] = 'Ainult administraatoril on õigus uuendada, logi sisse allpool.';
$lang['Only thumbnails prefix and webmaster mail address have been saved from previous configuration'] = 'Ainult pisipiltide eesliides ja veebimeistri epostiaadress on eelmistest seadistustest talletatud';
$lang['Perform a maintenance check in [Administration>Tools>Maintenance] if you encounter any problem.'] = 'Soorita hoolduskontroll [vt Administreerimine>Tööriistad>Hooldus] juhul kui sa märkad probleemi.';
$lang['SQL queries'] = 'SQL andmebaasi päring';
$lang['Statistics'] = 'Statistika';
$lang['This page proposes to upgrade your database corresponding to your old version of Piwigo to the current version. The upgrade assistant thinks you are currently running a <strong>release %s</strong> (or equivalent).'] = 'On soovitatud uuendada andmebaas Piwigo uuele versioonile. Uuendamisprogrammi abiline arvab et praegu jooksutatakse <strong>versiooni %s</strong> (või sellele vastavat).';
$lang['Upgrade from version %s to %s'] = 'Ueenda versioonilt %s versioonile %s';
$lang['Upgrade informations'] = 'Uuendusest lähemalt';
$lang['Upgrade'] = 'Uuenda';
$lang['User permissions and group permissions have been erased'] = 'Kasutajate ja gruppide kasutamisõigused on kustutatud';
$lang['You do not have access rights to run upgrade'] = 'Sul puudub õigus käivitada uuendust';
$lang['total SQL time'] = 'SQL aeg kokku';
$lang['total upgrade time'] = 'uuendamisel kulutatud aeg kokku';
?>

==> 14.5.0.zip: piwigo/language/et_EE/upgrade.lang.php <==
<?php
// +-----------------------------------------------------------------------+
// | This file is part of Piwigo.                                          |
// |                                                                       |
// | For copyright and license information, please view the COPYING.txt    |
// | file that was distributed with this source code.                      |
// +-----------------------------------------------------------------------+
$lang['All sub-albums of private albums become private'] = 'Privaatsete albumite kõik alam-albumid saavad samuti privaatseteks';
$lang['As a precaution, following plugins have been deactivated. You must check for plugins upgrade before reactiving them:'] = 'Ettevaatusabinõuks on järgmised pluginad deaktiveeritud. Sa pead vaatama kas neile on saadaval uuendusi, enne kui sa need aktiveerid.';
$lang['As a precaution, following themes have been deactivated. You must check for themes upgrade before reactiving them:'] = 'Ettevaatusabinõuks on järgmised teemad deaktiveeritud. Sa pead vaatama kas neile on saadaval uuendusi, enne kui sa need aktiveerid.';
$lang['In <i>%s</i>, before <b>?></b>, insert:'] = 'In <i>%s</i>, before <b>?></b>, insert:';
$lang['Only administrator can run upgrade: please sign in below.'] = 'Ainult administraatoril on õigus uuendada, logi sisse allpool.';
$lang['Only thumbnails prefix and webmaster mail address have been saved from previous configuration'] = 'Ainult pisipiltide eesliides ja veebimeistri epostiaadress on eelmistest seadistustest talletatud';
$lang['Perform a maintenance check in [Administration>Tools>Maintenance] if you encounter any problem.'] = 'Soorita hoolduskontroll [vt Administreerimine>Tööriistad>Hooldus] juhul kui sa märkad probleemi.';
$lang['SQL queries'] = 'SQL andmebaasi päring';
$lang['Statistics'] = 'Statistika';
$lang['This page proposes to upgrade your database corresponding to your old version of Piwigo to the current version. The upgrade assistant thinks you are currently running a <strong>release %s</strong> (or equivalent).'] = 'On soovitatud uuendada andmebaas Piwigo uuele versioonile. Uuendamisprogrammi abiline arvab et praegu jooksutatakse <strong>versiooni %s</strong> (või sellele vastavat).';
$lang['Upgrade from version %s to %s'] = 'Ueenda versioonilt %s versioonile %s';
$lang['Upgrade informations'] = 'Uuendusest lähemalt';
$lang['Upgrade'] = 'Uuenda';
$lang['User permissions and group permissions have been erased'] = 'Kasutajate ja gruppide kasutamisõigused on kustutatud';
$lang['You do not have access rights to run upgrade'] = 'Sul puudub õigus käivitada uuendust';
$lang['total SQL time'] = 'SQL aeg kokku';
$lang['total upgrade time'] = 'uuendamisel kulutatud aeg kokku';
$lang['Discover what\'s new in Piwigo %s'] = 'Vaata, mida on uut Piwigo %s-s';
